@@ -9,7 +9,8 @@
 #' @details
 #' This function does not cover `lavaan` models (`NULL` is returned).
 #'
-#' @param model a model object
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model object.
 #' @export
 #' @family model_helpers
 #' @examplesIf interactive()
@@ -83,8 +84,7 @@ model_compute_terms_contributions.default <- function(model) {
       } # stop
 
       # continuous variables converted to 1 to force positive values
-      d <- model |> purrr::pluck("data")
-      if (is.null(d)) d <- model |> model_get_model_frame()
+      d <- model |> model_get_model_frame()
 
       if (is.null(d)) {
         return(NULL)
